@@ -204,7 +204,8 @@ class OKULAR_EXPORT Generator : public QObject
             PageSizes,         ///< Whether the Generator can change the size of the document pages.
             PrintNative,       ///< Whether the Generator supports native cross-platform printing (QPainter-based).
             PrintPostscript,   ///< Whether the Generator supports postscript-based file printing.
-            PrintToFile        ///< Whether the Generator supports export to PDF & PS through the Print Dialog
+            PrintToFile,       ///< Whether the Generator supports export to PDF & PS through the Print Dialog
+            TiledRendering     ///< Whether the Generator can render tiles @since 0.16 (KDE 4.10)
         };
 
         /**
@@ -579,6 +580,36 @@ class OKULAR_EXPORT PixmapRequest
          */
         Page *page() const;
 
+        /**
+         * Sets whether the generator should render only the given normalized
+         * rect or the entire page
+         *
+         * @since 0.16 (KDE 4.10)
+         */
+        void setTile( bool tile );
+
+        /**
+         * Returns whether the generator should render just the region given by
+         * normalizedRect() or the entire page.
+         *
+         * @since 0.16 (KDE 4.10)
+         */
+        bool isTile() const;
+
+        /**
+         * Sets the region of the page to request.
+         *
+         * @since 0.16 (KDE 4.10)
+         */
+        void setNormalizedRect( const NormalizedRect &rect );
+
+        /**
+         * Returns the normalized region of the page to request.
+         *
+         * @since 0.16 (KDE 4.10)
+         */
+        const NormalizedRect& normalizedRect() const;
+
     private:
         Q_DISABLE_COPY( PixmapRequest )
 
