@@ -48,7 +48,7 @@ class PickPointEngine : public AnnotatorEngine
         {
             // parse engine specific attributes
             pixmapName = engineElement.attribute( "hoverIcon" );
-            QString stampname = m_annotElement.attribute( "icon" );
+            const QString stampname = m_annotElement.attribute( "icon" );
             if ( m_annotElement.attribute( "type" ) == "Stamp" && !stampname.simplified().isEmpty() )
                 pixmapName = stampname;
             center = QVariant( engineElement.attribute( "center" ) ).toBool();
@@ -115,7 +115,7 @@ class PickPointEngine : public AnnotatorEngine
             QRect boundrect = rect.geometry( (int)xScale, (int)yScale ).adjusted( 0, 0, 1, 1 );
             if ( m_block )
             {
-                Okular::NormalizedRect tmprect( qMin( startpoint.x, point.x ), qMin( startpoint.y, point.y ), qMax( startpoint.x, point.x ), qMax( startpoint.y, point.y ) );
+                const Okular::NormalizedRect tmprect( qMin( startpoint.x, point.x ), qMin( startpoint.y, point.y ), qMax( startpoint.x, point.x ), qMax( startpoint.y, point.y ) );
                 boundrect |= tmprect.geometry( (int)xScale, (int)yScale ).adjusted( 0, 0, 1, 1 );
             }
             return boundrect;
@@ -127,12 +127,12 @@ class PickPointEngine : public AnnotatorEngine
             {
                 if ( m_block )
                 {
-                    QPen origpen = painter->pen();
+                    const QPen origpen = painter->pen();
                     QPen pen = painter->pen();
                     pen.setStyle( Qt::DashLine );
                     painter->setPen( pen );
-                    Okular::NormalizedRect tmprect( qMin( startpoint.x, point.x ), qMin( startpoint.y, point.y ), qMax( startpoint.x, point.x ), qMax( startpoint.y, point.y ) );
-                    QRect realrect = tmprect.geometry( (int)xScale, (int)yScale );
+                    const Okular::NormalizedRect tmprect( qMin( startpoint.x, point.x ), qMin( startpoint.y, point.y ), qMax( startpoint.x, point.x ), qMax( startpoint.y, point.y ) );
+                    const QRect realrect = tmprect.geometry( (int)xScale, (int)yScale );
                     painter->drawRect( realrect );
                     painter->setPen( origpen );
                 }
@@ -151,14 +151,14 @@ class PickPointEngine : public AnnotatorEngine
 
             // find out annotation's type
             Okular::Annotation * ann = 0;
-            QString typeString = m_annotElement.attribute( "type" );
+            const QString typeString = m_annotElement.attribute( "type" );
             // create TextAnnotation from path
             if ( typeString == "FreeText")	//<annotation type="Text"
             {
                 //note dialog
-                QString prompt = i18n( "Text of the new note:" );
+                const QString prompt = i18n( "Text of the new note:" );
                 bool resok;
-                QString note = KInputDialog::getMultiLineText( i18n( "New Text Note" ), prompt, QString(), &resok );
+                const QString note = KInputDialog::getMultiLineText( i18n( "New Text Note" ), prompt, QString(), &resok );
                 if(resok)
                 {
                     //add note
@@ -173,12 +173,11 @@ class PickPointEngine : public AnnotatorEngine
                     rect.bottom = qMax(startpoint.y,point.y);
                     kDebug().nospace() << "xyScale=" << xscale << "," << yscale;
                     static int padding = 2;
-                    QFontMetricsF mf(ta->textFont());
-                    QRectF rcf = mf.boundingRect( Okular::NormalizedRect( rect.left, rect.top, 1.0, 1.0 ).geometry( (int)pagewidth, (int)pageheight ).adjusted( padding, padding, -padding, -padding ),
+                    const QFontMetricsF mf(ta->textFont());
+                    const QRectF rcf = mf.boundingRect( Okular::NormalizedRect( rect.left, rect.top, 1.0, 1.0 ).geometry( (int)pagewidth, (int)pageheight ).adjusted( padding, padding, -padding, -padding ),
                                                   Qt::AlignTop | Qt::AlignLeft | Qt::TextWordWrap, ta->inplaceText() );
                     rect.right = qMax(rect.right, rect.left+(rcf.width()+padding*2)/pagewidth);
                     rect.bottom = qMax(rect.bottom, rect.top+(rcf.height()+padding*2)/pageheight);
-                    ta->setBoundingRectangle( this->rect );
                     ta->window().setSummary( i18n( "Inline Note" ) );
                 }
             }
@@ -190,12 +189,11 @@ class PickPointEngine : public AnnotatorEngine
                 ta->setTextIcon( "Note" );
                 ta->window().setText( QString() );
                 //ta->window.flags &= ~(Okular::Annotation::Hidden);
-                double iconhei=0.03;
+                const double iconhei=0.03;
                 rect.left = point.x;
                 rect.top = point.y;
                 rect.right=rect.left+iconhei;
                 rect.bottom=rect.top+iconhei*xscale/yscale;
-                ta->setBoundingRectangle( this->rect );
                 ta->window().setSummary( i18n( "Note" ) );
             }
             // create StampAnnotation from path
@@ -209,12 +207,12 @@ class PickPointEngine : public AnnotatorEngine
                 rect.top = qMin( startpoint.y, point.y );
                 rect.right = qMax( startpoint.x, point.x );
                 rect.bottom = qMax( startpoint.y, point.y );
-                QRectF rcf = rect.geometry( (int)xscale, (int)yscale );
+                const QRectF rcf = rect.geometry( (int)xscale, (int)yscale );
                 const int ml = ( rcf.bottomRight() - rcf.topLeft() ).toPoint().manhattanLength();
                 if ( ml <= QApplication::startDragDistance() )
                 {
-                    double stampxscale = size / xscale;
-                    double stampyscale = size / yscale;
+                    const double stampxscale = size / xscale;
+                    const double stampyscale = size / yscale;
                     if ( center )
                     {
                         rect.left = point.x - stampxscale / 2;
@@ -228,7 +226,6 @@ class PickPointEngine : public AnnotatorEngine
                     rect.right = rect.left + stampxscale;
                     rect.bottom = rect.top + stampyscale;
                 }
-                sa->setBoundingRectangle( rect );
             }
             // create GeomAnnotation
             else if ( typeString == "GeomSquare" || typeString == "GeomCircle" )
@@ -246,7 +243,6 @@ class PickPointEngine : public AnnotatorEngine
                 rect.top = qMin( startpoint.y, point.y );
                 rect.right = qMax( startpoint.x, point.x );
                 rect.bottom = qMax( startpoint.y, point.y );
-                ga->setBoundingRectangle( rect );
             }
 
             // safety check
@@ -259,6 +255,20 @@ class PickPointEngine : public AnnotatorEngine
             if ( m_annotElement.hasAttribute( "opacity" ) )
                 ann->style().setOpacity( m_annotElement.attribute( "opacity", "1.0" ).toDouble() );
 
+            // set the bounding rectangle, and make sure that the newly created
+            // annotation lies within the page by translating it if necessary
+            if ( rect.right > 1 )
+            {
+                rect.left -= rect.right - 1;
+                rect.right = 1;
+            }
+            if ( rect.bottom > 1 )
+            {
+                rect.top -= rect.bottom - 1;
+                rect.bottom = 1;
+            }
+            ann->setBoundingRectangle( rect );
+
             // return annotation
             return QList< Okular::Annotation* >() << ann;
         }
@@ -316,15 +326,13 @@ class PolyLineEngine : public AnnotatorEngine
             {
                 movingpoint.x = nX;
                 movingpoint.y = nY;
-                QRect oldmovingrect = movingrect;
+                const QRect oldmovingrect = movingrect;
                 movingrect = rect | QRect( (int)( movingpoint.x * xScale ), (int)( movingpoint.y * yScale ), 1, 1 );
                 return oldmovingrect | movingrect;
             }
             else if ( type == Release )
             {
-                Okular::NormalizedPoint tmppoint;
-                tmppoint.x = nX;
-                tmppoint.y = nY;
+                const Okular::NormalizedPoint tmppoint(nX, nY);
                 if ( fabs( tmppoint.x - newPoint.x + tmppoint.y - newPoint.y ) > 1e-2 )
                     return rect;
 
@@ -356,8 +364,8 @@ class PolyLineEngine : public AnnotatorEngine
 
             if ( m_block && points.count() == 2 )
             {
-                Okular::NormalizedPoint first = points[0];
-                Okular::NormalizedPoint second = points[1];
+                const Okular::NormalizedPoint first = points[0];
+                const Okular::NormalizedPoint second = points[1];
                 // draw a semitransparent block around the 2 points
                 painter->setPen( m_engineColor );
                 painter->setBrush( QBrush( m_engineColor.light(), Qt::Dense4Pattern ) );
@@ -386,7 +394,7 @@ class PolyLineEngine : public AnnotatorEngine
 
             // find out annotation's type
             Okular::Annotation * ann = 0;
-            QString typeString = m_annotElement.attribute( "type" );
+            const QString typeString = m_annotElement.attribute( "type" );
 
             // create LineAnnotation from path
             if ( typeString == "Line" || typeString == "Polyline" || typeString == "Polygon" )
@@ -462,7 +470,7 @@ class TextSelectorEngine : public AnnotatorEngine
             {
                 lastPoint.x = nX;
                 lastPoint.y = nY;
-                QRect oldrect = rect;
+                const QRect oldrect = rect;
                 rect = QRect();
                 return oldrect;
             }
@@ -470,14 +478,14 @@ class TextSelectorEngine : public AnnotatorEngine
             {
                 if ( item() )
                 {
-                    QPoint start( (int)( lastPoint.x * item()->uncroppedWidth() ), (int)( lastPoint.y * item()->uncroppedHeight() ) );
-                    QPoint end( (int)( nX * item()->uncroppedWidth() ), (int)( nY * item()->uncroppedHeight() ) );
+                    const QPoint start( (int)( lastPoint.x * item()->uncroppedWidth() ), (int)( lastPoint.y * item()->uncroppedHeight() ) );
+                    const QPoint end( (int)( nX * item()->uncroppedWidth() ), (int)( nY * item()->uncroppedHeight() ) );
                     delete selection;
                     selection = 0;
                     Okular::RegularAreaRect * newselection = m_pageView->textSelectionForItem( item(), start, end );
                     if ( !newselection->isEmpty() )
                     {
-                        QList<QRect> geom = newselection->geometry( (int)xScale, (int)yScale );
+                        const QList<QRect> geom = newselection->geometry( (int)xScale, (int)yScale );
                         QRect newrect;
                         Q_FOREACH ( const QRect& r, geom )
                         {
@@ -527,7 +535,7 @@ class TextSelectorEngine : public AnnotatorEngine
 
             // find out annotation's type
             Okular::Annotation * ann = 0;
-            QString typeString = m_annotElement.attribute( "type" );
+            const QString typeString = m_annotElement.attribute( "type" );
 
             Okular::HighlightAnnotation::HighlightType type = Okular::HighlightAnnotation::Highlight;
             bool typevalid = false;
@@ -735,25 +743,26 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
         return QRect();
     }
 
-    // find out normalized mouse coords inside current item
-    const QRect & itemRect = item->uncroppedGeometry();
-    const QPointF eventPos = m_pageView->contentAreaPoint( pos );
-    double nX = item->absToPageX( eventPos.x() );
-    double nY = item->absToPageY( eventPos.y() );
-
-    QRect modifiedRect;
-
     // 1. lock engine to current item
-    if ( m_lockedItem && item != m_lockedItem )
-        return QRect();
     if ( !m_lockedItem && eventType == AnnotatorEngine::Press )
     {
         m_lockedItem = item;
         m_engine->setItem( m_lockedItem );
     }
+    if ( !m_lockedItem ) {
+        return QRect();
+    }
+
+    // find out normalized mouse coords inside current item
+    const QRect & itemRect = m_lockedItem->uncroppedGeometry();
+    const QPointF eventPos = m_pageView->contentAreaPoint( pos );
+    const double nX = qBound( 0.0, m_lockedItem->absToPageX( eventPos.x() ), 1.0 );
+    const double nY = qBound( 0.0, m_lockedItem->absToPageY( eventPos.y() ), 1.0 );
+
+    QRect modifiedRect;
 
     // 2. use engine to perform operations
-    QRect paintRect = m_engine->event( eventType, button, nX, nY, itemRect.width(), itemRect.height(), item->page() );
+    const QRect paintRect = m_engine->event( eventType, button, nX, nY, itemRect.width(), itemRect.height(), m_lockedItem->page() );
 
     // 3. update absolute extents rect and send paint event(s)
     if ( paintRect.isValid() )
@@ -763,7 +772,7 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
         m_lastDrawnRect = paintRect;
         m_lastDrawnRect.translate( itemRect.left(), itemRect.top() );
         // 3.2. decompose paint region in rects and send paint events
-        QVector<QRect> rects = compoundRegion.unite( m_lastDrawnRect ).rects();
+        const QVector<QRect> rects = compoundRegion.unite( m_lastDrawnRect ).rects();
         const QPoint areaPos = m_pageView->contentAreaPosition();
         for ( int i = 0; i < rects.count(); i++ )
             m_pageView->viewport()->update( rects[i].translated( -areaPos ) );
@@ -786,7 +795,7 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
             m_document->addPageAnnotation( m_lockedItem->pageNumber(), annotation );
             
             if ( annotation->openDialogAfterCreation() )
-                m_pageView->openAnnotationWindow( annotation, item->pageNumber() );
+                m_pageView->openAnnotationWindow( annotation, m_lockedItem->pageNumber() );
         }
 
         if ( m_continuousMode )
@@ -800,8 +809,6 @@ QRect PageViewAnnotator::performRouteMouseOrTabletEvent(const AnnotatorEngine::E
 
 QRect PageViewAnnotator::routeMouseEvent( QMouseEvent * e, PageViewItem * item )
 {
-    if ( !item ) return QRect();
-
     AnnotatorEngine::EventType eventType;
     AnnotatorEngine::Button button;
 
@@ -947,7 +954,7 @@ void PageViewAnnotator::slotToolSelected( int toolID )
             // display the tooltip
             else if ( toolSubElement.tagName() == "tooltip" )
             {
-                QString tip = toolSubElement.text();
+                const QString tip = toolSubElement.text();
                 if ( !tip.isEmpty() )
                     m_pageView->displayMessage( i18nc( "Annotation tool", tip.toUtf8() ), QString(), PageViewMessage::Annotation );
             }
